summaryrefslogtreecommitdiff
path: root/nuttx/include/net/uip/uip-arp.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-14 23:32:23 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-14 23:32:23 +0000
commitd7d4a0d765d12cc152c62a37b490702c39d76447 (patch)
treed3969c50e49cd742124e05349431556344a93f54 /nuttx/include/net/uip/uip-arp.h
parent313eb5bb780f9e9baa353651996b51ce33a85fca (diff)
downloadpx4-nuttx-d7d4a0d765d12cc152c62a37b490702c39d76447.tar.gz
px4-nuttx-d7d4a0d765d12cc152c62a37b490702c39d76447.tar.bz2
px4-nuttx-d7d4a0d765d12cc152c62a37b490702c39d76447.zip
Switching to C99 stdint.h types
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@2340 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/net/uip/uip-arp.h')
-rw-r--r--nuttx/include/net/uip/uip-arp.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/nuttx/include/net/uip/uip-arp.h b/nuttx/include/net/uip/uip-arp.h
index 134293ece..47b5b9992 100644
--- a/nuttx/include/net/uip/uip-arp.h
+++ b/nuttx/include/net/uip/uip-arp.h
@@ -46,8 +46,9 @@
****************************************************************************/
#include <nuttx/config.h>
-#include <sys/types.h>
#include <nuttx/compiler.h>
+
+#include <stdint.h>
#include <net/ethernet.h>
#include <net/uip/uip.h>
@@ -72,9 +73,9 @@
struct uip_eth_hdr
{
- uint8 dest[6]; /* Ethernet destination address (6 bytes) */
- uint8 src[6]; /* Ethernet source address (6 bytes) */
- uint16 type; /* Type code (2 bytes) */
+ uint8_t dest[6]; /* Ethernet destination address (6 bytes) */
+ uint8_t src[6]; /* Ethernet source address (6 bytes) */
+ uint16_t type; /* Type code (2 bytes) */
};
/* One entry in the ARP table (volatile!) */
@@ -83,7 +84,7 @@ struct arp_entry
{
in_addr_t at_ipaddr; /* IP address */
struct ether_addr at_ethaddr; /* Hardware address */
- uint8 at_time;
+ uint8_t at_time;
};
/****************************************************************************
@@ -181,15 +182,15 @@ EXTERN void uip_arp_timer(void);
* address of an existing association.
*
* Input parameters:
* pipaddr - Refers to an IP address uint16[2] in network order
* ethaddr - Refers to a HW address uint8[IFHWADDRLEN]
*
* Assumptions
* Interrupts are disabled
*
****************************************************************************/
-EXTERN void uip_arp_update(uint16 *pipaddr, uint8 *ethaddr);
+EXTERN void uip_arp_update(uint16_t *pipaddr, uint8_t *ethaddr);
/****************************************************************************
* Name: uip_arp_find
@@ -181,15 +182,15 @@ EXTERN void uip_arp_timer(void);
*
* Input parameters:
- * pipaddr - Refers to an IP address uint16[2] in network order
- * ethaddr - Refers to a HW address uint8[IFHWADDRLEN]
+ * pipaddr - Refers to an IP address uint16_t[2] in network order
+ * ethaddr - Refers to a HW address uint8_t[IFHWADDRLEN]
*
* Assumptions